Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(259)

Unified Diff: tools/bots/sdk_dartino_patched.py

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/bots/fletch_namer.py ('k') | tools/bots/sdk_fletch_patched.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/bots/sdk_dartino_patched.py
diff --git a/tools/bots/sdk_fletch_patched.py b/tools/bots/sdk_dartino_patched.py
similarity index 88%
rename from tools/bots/sdk_fletch_patched.py
rename to tools/bots/sdk_dartino_patched.py
index 66b8dcf2776cdafdefb5779eda28537fcc75dbb7..609208a4ecbb59666c0029e41fd663d094729fdb 100644
--- a/tools/bots/sdk_fletch_patched.py
+++ b/tools/bots/sdk_dartino_patched.py
@@ -5,11 +5,11 @@
# BSD-style license that can be found in the LICENSE file.
"""
-Buildbot steps for building Dart SDK with Fletch-specific patches.
+Buildbot steps for building Dart SDK with Dartino-specific patches.
"""
import os
import sys
# We run this as third_party/fletch/tools/bots/sdk_fletch_patched.py
sys.path.insert(0, os.path.join('tools', 'bots'))
import bot
@@ -18,7 +18,7 @@ import re
utils = bot_utils.GetUtils()
-PATCHED_BUILDER = r'dart-sdk-fletch-patched-(linux|mac)-(x64|arm)'
+PATCHED_BUILDER = r'dart-sdk-dartino-patched-(linux|mac)-(x64|arm)'
def BuildConfig(name, is_buildbot):
"""Returns info for the current buildbot."""
@@ -51,7 +51,7 @@ def BuildSteps(build_info):
build_info.mode,
build_info.arch)
revision = utils.GetGitRevision()
- archive_path = 'fletch-archive/patched_dart_sdks/%s/' % revision
+ archive_path = 'dartino-archive/patched_dart_sdks/%s/' % revision
stripped_name = '%sdart-vm-%s-%s' % (archive_path, build_info.arch,
build_info.system)
unstripped_name = '%sdart-vm-%s-%s-symbols' % (archive_path,
@@ -5,11 +5,11 @@
import os
import sys
-# We run this as third_party/fletch/tools/bots/sdk_fletch_patched.py
+# We run this as third_party/dartino/tools/bots/sdk_dartino_patched.py
sys.path.insert(0, os.path.join('tools', 'bots'))
import bot
« no previous file with comments | « tools/bots/fletch_namer.py ('k') | tools/bots/sdk_fletch_patched.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698